import React, { useEffect, useState } from 'react';
import { getList } from '../../../../database/statisticsService';
import { Header, HorizontalTabView, Loading, PageWrapper } from '../../../../components';

const StatisticsScreen = () => {
  const [index, setIndex] = useState(0);
  const [routes, setRoutes] = useState<{ key: string; title: string }[]>([]);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const types = getList();

    const parseRoutes = types?.map((item) => ({
      key: item.name,
      list: item.list,
      sublist: item.sublists,
      title: item.name
    }));

    setRoutes(parseRoutes || []);
    setLoading(false);
  }, []);

  if (loading) return <Loading />;

  return (
    <>
      <PageWrapper>
        <Header label={'Statistics'} />
        <HorizontalTabView
          index={index}
          setIndex={setIndex}
          withMark={true}
          routes={routes}
          renderScene={({ route }: { route: { key: string; title: string } }) => <></>}
        />
      </PageWrapper>
    </>
  );
};

export default StatisticsScreen;
